Operator graph optimization tools
=================================

These functions are used to restructure the operator graph so that it can
be simulated more efficiently when converted into a TensorFlow graph.

.. automodule:: nengo_dl.graph_optimizer